/*
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */


do_print("** Performing Subtest 1 **")

do_subtest("tests/subtest1.js");

do_print("** Performing Subtest 2 **")

do_subtest("tests/subtest2.js");

